@@ -1,3 +1,5 @@
+import typing
+from enum import IntFlag
 from typing import Tuple, List, Optional
 
 from asn1editor.interfaces.BitstringInterface import BitstringInterface
@@ -6,11 +8,18 @@ from asn1editor.interfaces.ValueInterface import ValueInterface
 from asn1editor.view.AbstractView import AbstractView, ContainerView, ListView, ChoiceView
 
 
+class Styles(IntFlag):
+    READ_ONLY = 1
+    HIDDEN = 2
+
+
 class TypeInfo:
     name: str = ''
     tag: str = ''
     typename: str = ''
     optional: bool = False
+    style: Styles = 0
+    help: typing.Optional[str] = None
 
 
 class AbstractViewFactory:  # pragma: no cover
